"""The plotext package allows you to plot data directly on terminal."""

from plotext.plot import *
name = "plotext"
__version__ = "1.0.11"